#  Render script for Blender
#  Copyright (c)  Holger Schoenberger - Binary Alchemy


bl_info = {
    "name": "BA Intel Performance Fix",
    "author": "Binary Alchemy",
    "version": "1.0",
    "blender": (3, 0, 0),
    "description": "Fixed the Blender bug that performance cores are not used",
    "category": "Render",
    }

import bpy
import sys
import os
import datetime
import ctypes


def flush_log():
    sys.stdout.flush()
    sys.stderr.flush()

def log_message_base(lvl, msg):
    msg_start = datetime.datetime.now().strftime("' %H:%M.%S") + " baBlend"

    if (lvl):
        print(f"{msg_start} - {str(lvl)}: {str(msg)}")
    else:
        print(f"{msg_start}      : {str(msg)}")

def log_msg(msg):
    log_message_base("", msg)

def log_msg_dbg(msg):
    #log_message_base("DBG", msg)
    pass

def log_msg_wrn(msg):
    log_message_base("WRN", msg)

def log_msg_err(msg):
    log_message_base("ERR", str(msg)+"\n\n")
    log_message_base("ERR", "Error reported, aborting render script")
    global wasError_Close
    wasError_Close=True
    bpy.ops.wm.quit_blender()




def useAllCores():
    if not sys.platform.lower().startswith("win"):
        return
    log_msg("Binary Alchemy: Enabling performance cores for Intel 12th+ ...")
    
    try:
        dllFileName= os.path.realpath(os.path.dirname(__file__))
        dllFileName= os.path.join(dllFileName, "rrExternal.dll")
        lib = ctypes.CDLL(dllFileName)

        # Your function signature: int example_func(int, float)
        lib.winApi_useAllCores.restype = ctypes.c_bool
        result= lib.winApi_useAllCores()
        if result:
            log_msg("Success! Now unleash the power of all cores!")
        else:
            log_msg_wrn("Failed!")

    except Exception as e:
        log_msg_wrn(e)
        import traceback
        log_msg_wrn(traceback.format_exc())  # log and quit






def register():
    useAllCores()


def unregister():
    pass

